pub struct ConditionalProfileFlags {
pub condition: Condition,
pub flags: ProfileFlags,
}Expand description
Conditional [target.'cfg(...)'.profile] block. Same shape as
ProfileFlags but tagged with the predicate that gates it.
Fields
condition: Conditionflags: ProfileFlagsTrait Implementations
Sourceimpl Clone for ConditionalProfileFlags
impl Clone for ConditionalProfileFlags
Sourcefn clone(&self) -> ConditionalProfileFlags
fn clone(&self) -> ConditionalProfileFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConditionalProfileFlags
impl Debug for ConditionalProfileFlags
Sourceimpl<'de> Deserialize<'de> for ConditionalProfileFlags
impl<'de> Deserialize<'de> for ConditionalProfileFlags
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ConditionalProfileFlags
impl PartialEq for ConditionalProfileFlags
Sourcefn eq(&self, other: &ConditionalProfileFlags) -> bool
fn eq(&self, other: &ConditionalProfileFlags) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ConditionalProfileFlags
impl Serialize for ConditionalProfileFlags
impl Eq for ConditionalProfileFlags
impl StructuralPartialEq for ConditionalProfileFlags