pub struct ToolDetection<I, C> {
pub path: PathBuf,
pub identity: I,
pub capabilities: C,
}Expand description
One tool’s detection outcome plus the path it was invoked at.
path is the resolved absolute path from
crate::ResolvedToolchain; it is preserved here so error
messages can mention the exact executable.
Fields
path: PathBufidentity: Icapabilities: CTrait Implementations
Sourceimpl<I: Clone, C: Clone> Clone for ToolDetection<I, C>
impl<I: Clone, C: Clone> Clone for ToolDetection<I, C>
Sourcefn clone(&self) -> ToolDetection<I, C>
fn clone(&self) -> ToolDetection<I, C>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de, I, C> Deserialize<'de> for ToolDetection<I, C>where
I: Deserialize<'de>,
C: Deserialize<'de>,
impl<'de, I, C> Deserialize<'de> for ToolDetection<I, C>where
I: Deserialize<'de>,
C: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<I: PartialEq, C: PartialEq> PartialEq for ToolDetection<I, C>
impl<I: PartialEq, C: PartialEq> PartialEq for ToolDetection<I, C>
Sourcefn eq(&self, other: &ToolDetection<I, C>) -> bool
fn eq(&self, other: &ToolDetection<I, C>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<I, C> Serialize for ToolDetection<I, C>
impl<I, C> Serialize for ToolDetection<I, C>
impl<I: Eq, C: Eq> Eq for ToolDetection<I, C>
impl<I, C> StructuralPartialEq for ToolDetection<I, C>