pub struct ProfileDefaults {
pub debug: bool,
pub opt_level: OptLevel,
pub assertions: bool,
}Expand description
Concrete defaults for one profile. Used to seed inheritance before any manifest overrides apply.
Fields
debug: boolopt_level: OptLevelassertions: boolTrait Implementations
Sourceimpl Clone for ProfileDefaults
impl Clone for ProfileDefaults
Sourcefn clone(&self) -> ProfileDefaults
fn clone(&self) -> ProfileDefaults
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileDefaults
impl Debug for ProfileDefaults
Sourceimpl PartialEq for ProfileDefaults
impl PartialEq for ProfileDefaults
Sourcefn eq(&self, other: &ProfileDefaults) -> bool
fn eq(&self, other: &ProfileDefaults) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ProfileDefaults
impl Eq for ProfileDefaults
impl StructuralPartialEq for ProfileDefaults