pub enum ToolKind {
CCompiler,
CxxCompiler,
Archiver,
}Expand description
Which kind of tool a selection refers to.
Variants
CCompiler
C compiler (driver, e.g. cc, clang, gcc).
CxxCompiler
C++ compiler (driver, e.g. c++, clang++, g++). Also
drives linking in the current backend.
Archiver
Static-library archiver (e.g. ar, llvm-ar).
Implementations
Sourceimpl ToolKind
impl ToolKind
Sourcepub fn as_key(self) -> &'static str
pub fn as_key(self) -> &'static str
Stable, lower-case identifier used in CLI flags, manifest keys, JSON serialization, and error messages.
Sourcepub fn human_label(self) -> &'static str
pub fn human_label(self) -> &'static str
Human-readable label used in error messages so users can map the failure back to the tool they were thinking about.