pub struct DeclaredPatch {
pub source: PatchSource,
pub declared_in: PathBuf,
pub provenance: PatchProvenance,
}Expand description
One patch entry as declared in a single source file. Carries
the relative source value plus the absolute path of the file
that declared it so the orchestration layer can resolve any
relative paths against the right base directory.
Fields
source: PatchSourcedeclared_in: PathBufAbsolute path of the file that declared this patch
(cabin.toml for manifest patches, .cabin/config.toml
for config patches). Used as the base for resolving
relative path values.
provenance: PatchProvenanceTrait Implementations
Sourceimpl Clone for DeclaredPatch
impl Clone for DeclaredPatch
Sourcefn clone(&self) -> DeclaredPatch
fn clone(&self) -> DeclaredPatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeclaredPatch
impl Debug for DeclaredPatch
Sourceimpl PartialEq for DeclaredPatch
impl PartialEq for DeclaredPatch
Sourcefn eq(&self, other: &DeclaredPatch) -> bool
fn eq(&self, other: &DeclaredPatch) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DeclaredPatch
impl StructuralPartialEq for DeclaredPatch